---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

## User story

Is your feature request related to a problem? Please provide a clear and concise description of what the problem is. Ex. _I'm always frustrated when doing [...], which is a common thing to do in case of [...]._

## Proposal

Describe the solution you'd like - a clear and concise description of what you want to happen. It's fine to describe the outcome without thinking about how that would be possible/ should be implemented, or give specific details on how you imagine something being achieved.
